@@ -5,11 +5,11 @@ use strict;
 #use bytes;
 
 our @EXPORT    = qw( sendmsg recvmsg );
-our @EXPORT_OK = qw( pack_cmsghdr unpack_cmsghdr );
-our $VERSION = '0.04';
+our @EXPORT_OK = qw( pack_cmsghdr unpack_cmsghdr ); # Undocumented!
+our $VERSION = '0.05';
 
 # Forcibly export our sendmsg, recvmsg methods
-INIT {
+BEGIN {
   *IO::Socket::sendmsg = \&sendmsg;
   *IO::Socket::recvmsg = \&recvmsg;
 }
@@ -23,7 +23,7 @@ sub flags {
   $self->{flags};
 }
 
-INIT {
+BEGIN {
   for my $attr (qw|name buf control|) {
     no strict 'refs';
 
@@ -280,13 +280,11 @@ module.
 
 =head1 SEE ALSO
 
-L<sendmsg(2)>, L<recvmsg(2)>, L<File::FDpasser>, L<"RFC 2292">
+L<sendmsg(2)>, L<recvmsg(2)>, L<File::FDpasser>, L<RFC 2292|https://tools.ietf.org/html/rfc2292>
 
 =head1 AUTHOR
 
-Michael J. Pomraning
-
-Please report bugs to E<lt>mjp AT cpan DOT org E<gt>
+Michael J. Pomraning, co-maintained by Felipe Gasper
 
 =head1 COPYRIGHT AND LICENSE
 
